==> haskell-vector-0.13.2.0-332-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector
version:              0.13.2.0
visibility:           public
id:                   vector-0.13.2.0-7G06w2o8kW4KnbCWBZDKly
key:                  vector-0.13.2.0-7G06w2o8kW4KnbCWBZDKly
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  3bbfc2bba7a56ab365acca42ada45ace
exposed:              True
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Strict Data.Vector.Strict.Mutable Data.Vector.Unboxed
    Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-7G06w2o8kW4KnbCWBZDKly
include-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0/include
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    primitive-0.9.1.0-3wcULVX324m4b7zw32DKNg
    vector-stream-0.1.0.1-B3eeou3yuYd7g2aD4u5s22

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-vector-z-benchmarks-O2
version:              0.13.2.0
package-name:         vector
lib-name:             benchmarks-O2
visibility:           public
id:                   vector-0.13.2.0-JsXgBRaDYMoBznsFdIWQeX-benchmarks-O2
key:                  vector-0.13.2.0-JsXgBRaDYMoBznsFdIWQeX-benchmarks-O2
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  fecd4327cefbf0d956fbcce73ecab9f0
exposed-modules:
    Bench.Vector.Algo.AwShCC Bench.Vector.Algo.FindIndexR
    Bench.Vector.Algo.HybCC Bench.Vector.Algo.Leaffix
    Bench.Vector.Algo.ListRank Bench.Vector.Algo.MutableSet
    Bench.Vector.Algo.NextPermutation Bench.Vector.Algo.Quickhull
    Bench.Vector.Algo.Rootfix Bench.Vector.Algo.Spectral
    Bench.Vector.Algo.Tridiag Bench.Vector.Tasty
    Bench.Vector.TestData.Graph Bench.Vector.TestData.ParenTree

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-JsXgBRaDYMoBznsFdIWQeX-benchmarks-O2
depends:
    base-4.18.2.1 random-1.2.1.3-HzFGhfPSv5b3eeTVe0g48p
    tasty-1.5.2-Bc3LD4OZ5taJ9AlqqiAeZ8
    vector-0.13.2.0-7G06w2o8kW4KnbCWBZDKly

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-0.13.2.0-333-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector
version:              0.13.2.0
visibility:           public
id:                   vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi
key:                  vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  b27afde1cf9a81e9cc407708b344024c
exposed:              True
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Strict Data.Vector.Strict.Mutable Data.Vector.Unboxed
    Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi
include-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0/include
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    primitive-0.9.1.0-3wcULVX324m4b7zw32DKNg
    vector-stream-0.1.0.1-B3eeou3yuYd7g2aD4u5s22

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-vector-z-benchmarks-O2
version:              0.13.2.0
package-name:         vector
lib-name:             benchmarks-O2
visibility:           public
id:                   vector-0.13.2.0-FNmEe0nFFz09jjSWZP8kdu-benchmarks-O2
key:                  vector-0.13.2.0-FNmEe0nFFz09jjSWZP8kdu-benchmarks-O2
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  4a4d24066845a76d1236873ef253c31b
exposed-modules:
    Bench.Vector.Algo.AwShCC Bench.Vector.Algo.FindIndexR
    Bench.Vector.Algo.HybCC Bench.Vector.Algo.Leaffix
    Bench.Vector.Algo.ListRank Bench.Vector.Algo.MutableSet
    Bench.Vector.Algo.NextPermutation Bench.Vector.Algo.Quickhull
    Bench.Vector.Algo.Rootfix Bench.Vector.Algo.Spectral
    Bench.Vector.Algo.Tridiag Bench.Vector.Tasty
    Bench.Vector.TestData.Graph Bench.Vector.TestData.ParenTree

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-FNmEe0nFFz09jjSWZP8kdu-benchmarks-O2
depends:
    base-4.18.2.1 random-1.2.1.3-HzFGhfPSv5b3eeTVe0g48p
    tasty-1.5.2-8UD20z9n5eiHm9q6FlO2Zy
    vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
